#
# spec file for package perl-Sereal
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Sereal
Version:        4.018
Release:        pm152.17.1
%define cpan_name Sereal
Summary:        Binary serialization module for Perl
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/Y/YV/YVES/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Sereal::Decoder) >= 4.018
BuildRequires:  perl(Sereal::Encoder) >= 4.018
BuildRequires:  perl(Test::LongString)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Warn)
Requires:       perl(Sereal::Decoder) >= 4.018
Requires:       perl(Sereal::Encoder) >= 4.018
%{perl_requires}

%description
_Sereal_ is an efficient, compact-output, binary and feature-rich
serialization protocol. The Perl encoder is implemented as the
Sereal::Encoder module, the Perl decoder correspondingly as
Sereal::Decoder. They are distributed separately to allow for safe
upgrading without downtime. (Hint: Upgrade the decoder everywhere first,
then the encoder.)

This 'Sereal' module is a very thin wrapper around both 'Sereal::Encoder'
and 'Sereal::Decoder'. It depends on both and loads both. So if you have a
user of both encoder and decoder, it is enough to depend on a particular
version of 'Sereal' and you'll get the most recent released versions of
'Sereal::Encoder' and 'Sereal::Decoder' whose version is smaller than or
equal to the version of 'Sereal' you depend on.

The protocol specification and many other bits of documentation can be
found in the github repository. Right now, the specification is at
https://github.com/Sereal/Sereal/blob/master/sereal_spec.pod, there is a
discussion of the design objectives in
https://github.com/Sereal/Sereal/blob/master/README.pod, and the output of
our benchmarks can be seen at
https://github.com/Sereal/Sereal/wiki/Sereal-Comparison-Graphs.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README

%changelog
* Tue Aug  4 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.018
  see /usr/share/doc/packages/perl-Sereal/Changes
  4.018 Thurs Aug 3, 2020
  * Fix issue with gcc 10 with snappy compression.
* Fri Jul 10 2020 Tina Müller <timueller+perl@suse.de>
- updated to 4.017
  see /usr/share/doc/packages/perl-Sereal/Changes
  4.017 Thurs July 9, 2020
  * The build fixes in 4.016 didn't work correctly, this should fix them.
  4.016 Thurs July 9, 2020
  * Fix some dependency issues in build process
  4.015 Weds  July 8, 2020
  * Build fixes (missing dependency)
  * Hardening against corrupted data
  * New thresholds to manage decoding process
  4.014 Thurs June 11, 2020
  * Fix build issue on non-win32 platforms.
  * Update zstd to 1.4.5
  4.012 Tues February 4, 2020
  * Fix memory leak in looks_like_sereal(), thanks to Kirill Sysoev
* Wed Feb  5 2020 <timueller+perl@suse.de>
- updated to 4.011
  see /usr/share/doc/packages/perl-Sereal/Changes
  4.011 Tues February 4, 2020
  * Fix and test custom opcode logic for 5.31.2 and later.
  4.010 Tues February 4, 2020
  * Encoder/Decoder: Update miniz
  * Encoder/Decoder: Update zstd
  * Sereal/Encoder/Decoder: perltidy perl code to a standard style
* Sat Feb  1 2020 <timueller+perl@suse.de>
- updated to 4.009
  see /usr/share/doc/packages/perl-Sereal/Changes
  4.009 Fri January 31, 2020
  * Encoder/Decoder: Update ppport.h for modern perls.
  4.008 Thurs Jan 30, 2020
  * Encoder/Decoder: Build fixes for modern perls.
  * Encoder/Decoder: Pod fixes
* Wed Apr 10 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.007
  see /usr/share/doc/packages/perl-Sereal/Changes
  4.007 Tues Apr 9, 2019
  * Sereal: restore write_sereal(), read_sereal() as aliases to write_sereal_file()
    and read_sereal_file(). Better tests for exported subs. Add SRL_UNCOMPRESSED,
    SRL_SNAPPY, SRL_ZLIB, SRL_ZSTD exports.
  * Decoder: tweak docs for looks_like_sereal/scalar_looks_like_sereal
  4.006 Mon Apr 8, 2019
  * Sereal: fix read_sereal_file(),
* Tue Apr  9 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.006
  see /usr/share/doc/packages/perl-Sereal/Changes
* Wed Nov  7 2018 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of summary.
* Sun Oct  7 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix autogenerated changes
* Wed Feb  7 2018 coolo@suse.com
- updated to 4.005
  see /usr/share/doc/packages/perl-Sereal/Changes
* Sun Sep  4 2016 coolo@suse.com
- updated to 3.015
  see /usr/share/doc/packages/perl-Sereal/Changes
* Fri Sep  2 2016 coolo@suse.com
- updated to 3.015
  see /usr/share/doc/packages/perl-Sereal/Changes
  3.015 Thu Sep  1 20:18:44 CEST 2016
  * Fix builds under 5.25+
  * Fix various buffer overun bugs found using AFL (thanks to dgryski)
  * Fix issue in decode_from_file()
* Thu Dec 10 2015 coolo@suse.com
- updated to 3.014
  see /usr/share/doc/packages/perl-Sereal/Changes
* Mon Nov 16 2015 coolo@suse.com
- updated to 3.006
  see /usr/share/doc/packages/perl-Sereal/Changes
  3.006 Nov 14 2015
  * [DECODER] fix segfaults from heavily corrupted data. Guards
    against various pathological cases which could cause segfaults
    fixed. Thanks to Damian Gryski and "fuzzing sereal with afl"
    for finding these cases.
  * [ENCODER] Various subtle fixes to how we choose whether to serialize
    the string or numeric version of a value, in particular to
    ensure that "00" always round trips as "00", and related issues.
    Note this fix has correctness and performance consequences. In
    some cases values that used to serialized as integers (arguably
    incorrectly) will be serialized as strings instead, and some code
    maybe be slower to serialize.
    NOTE: Some issues related to this subject are not fixable without
    a protocol change. In particular this change may affect the behavior
    of code that uses binary logical operators on values serialized
    with Perl.
    Thanks to Zefram, Tom, and others for help with this issue.
  * Fixups for cast warnings under -Wint-to-ptr builds by using
    using PTR2INT and INT2PTR for casting our objects.
  * Win32 fixes
  * Build improvements
  * Changes to how we generate constants
* Sat May  9 2015 coolo@suse.com
- initial package $version
  * created by $NAME $VERSION
